Crate tiger_pkg

Crate tiger_pkg 

Tiger PKG Library

Latest version Documentation

You need an oo2core DLL to be able to decompress packages. When using tiger-pkg with a Destiny 2/Marathon installation, PackageManager will automatically search for oo2core under bin\x64.

In any other case, you will need to get oo2core_3_win64.dll from somewhere (an old game for example), and place it in the directory where you run tiger-pkg from. Check below for the version of oo2core that is required for your game.

On Linux, liblinoodle is used for oo2core_3 support (which requires the respective Windows DLL), while liboodle-data-shared.so is used for oo2core_9 support (which does not require the Windows DLL and can be used on it’s own). liboodle-data-shared.so can be downloaded here (you will want to download clang.zip or gcc.zip)

Package format support

VersionPlatformWorks?Oodle Library
Destiny Internal AlphaX360oo2core_3_win64.dll
Destiny Legacy (The Taken King)PS3/X360/PS4/XONEoo2core_3_win64.dll
Destiny (Rise of Iron)PS4/XONEoo2core_3_win64.dll
Destiny 2 (Beta)Anyoo2core_3_win64.dll
Destiny 2 (Pre-BL)Anyoo2core_3_win64.dll
Destiny 2 (Post-BL)Anyoo2core_9_win64.dll / liboodle-data-shared.so
MarathonAnyoo2core_9_win64.dll / liboodle-data-shared.so

Game version codes

Destiny

VersionCode
Destiny (Internal Alpha)d1_devalpha
Destiny (First Look Alpha)d1_fla
Destiny: The Taken Kingd1_ttk
Destiny: Rise of Irond1_roi
Destiny 2 (Beta)d2_beta
Destiny 2: Forsakend2_fs
Destiny 2: Shadowkeepd2_sk
Destiny 2: Beyond Lightd2_bl
Destiny 2: Witch Queend2_wq
Destiny 2: Lightfalld2_lf
Destiny 2: The Final Shaped2_tfs
Destiny 2: The Edge of Fated2_eof
Destiny 2: Renegadesd2_renegades

Marathon

VersionCode
Marathon (Alpha/Test Builds)goliath_alpha
Marathon*goliath
* Includes server slam build

Platform codes

PlatformCode
Xbox 360x360
Xbox Onexboxone
PlayStation 3ps3
PlayStation 4ps4
Windows (x64)w64

Re-exports

pub use manager::PackageManager;
pub use package::Package;
pub use package::PackageLanguage;
pub use package::PackagePlatform;
pub use tag::TagHash;
pub use tag::TagHash64;
pub use version::DestinyVersion;
pub use version::GameVersion;
pub use version::MarathonVersion;
pub use version::Version;

Modules

manager
package
tag
version

Structs

PackageD2PreBL
PackageNamedTagEntry

Enums

Endian
Defines the order of bytes in a multi-byte type.

Functions

has_pkg_key
register_pkg_key